/* ============================================================================
 * File Name: `$INSTANCE_NAME`.c
 * Version `$CY_MAJOR_VERSION`.`$CY_MINOR_VERSION`
 *
 * Description:
 *   DDS24: 24-bit DDS frequency generator component (v 0.0)
 *   Produces two syncronous fractional frequency outputs (out1 and out2)
 *   Outputs out1 and out2 separated by variable 8-bit phase shift [0..255]. 
 *
 * Credits:
 *   based on original IQ_DDS code by <PSoC73>:
 *   http://www.cypress.com/?app=forum&id=2492&rID=88149
 * 
 *   Special thanks to <pavloven>, <vdvorak>, <kabron>
 *
 * Note:
 *   frequency resolution = clock_frequency / 2^24
 *   frequency maximum    = clock_frequency / 2
 *   frequency minimum    = clock_frequency / 2^24
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/

#include <`$INSTANCE_NAME`.h>





  
//==============================================================================
// Set control output value
//==============================================================================

void  `$INSTANCE_NAME`_Write( uint32 val ) // 
{   
    /*
        CY_SET_REG8( `$INSTANCE_NAME`_out0_PTR,  val     &0xFF ); //
        
    #if (`$INSTANCE_NAME`_BUS_WIDTH > 8)
        CY_SET_REG8( `$INSTANCE_NAME`_out1_PTR, (val>> 8)&0xFF ); //
    #endif
        
    #if (`$INSTANCE_NAME`_BUS_WIDTH > 16)
        CY_SET_REG8( `$INSTANCE_NAME`_out2_PTR, (val>>16)&0xFF ); //
    #endif
        
    #if (`$INSTANCE_NAME`_BUS_WIDTH > 24)
        CY_SET_REG8( `$INSTANCE_NAME`_out3_PTR, (val>>24)&0xFF ); // 
    #endif
    */
    
    /*
    // alternative->
    #if   (`$INSTANCE_NAME`_BUS_WIDTH <= 8u)
                CY_SET_REG8( `$INSTANCE_NAME`_out0_PTR,  val     &0xFF ); //
    
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 16u)
                CY_SET_REG8( `$INSTANCE_NAME`_out0_PTR,  val     &0xFF ); //
                CY_SET_REG8( `$INSTANCE_NAME`_out1_PTR, (val>> 8)&0xFF ); //
         
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 24u)
                CY_SET_REG8( `$INSTANCE_NAME`_out0_PTR,  val     &0xFF ); //
                CY_SET_REG8( `$INSTANCE_NAME`_out1_PTR, (val>> 8)&0xFF ); //
                CY_SET_REG8( `$INSTANCE_NAME`_out2_PTR, (val>>16)&0xFF ); //
 
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 32u)
                CY_SET_REG8( `$INSTANCE_NAME`_out0_PTR,  val     &0xFF ); //
                CY_SET_REG8( `$INSTANCE_NAME`_out1_PTR, (val>> 8)&0xFF ); //
                CY_SET_REG8( `$INSTANCE_NAME`_out2_PTR, (val>>16)&0xFF ); //
                CY_SET_REG8( `$INSTANCE_NAME`_out3_PTR, (val>>24)&0xFF ); // 
    #endif
    */
    
    
    // alternative 2->
    #if   (`$INSTANCE_NAME`_BUS_WIDTH <= 8u)
                *(reg8*) `$INSTANCE_NAME`_sControl_ControlByte0__CONTROL_REG = val &0xFF; //
                // *`$INSTANCE_NAME`_out0_PTR = val &0xFF; //
    
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 16u)
                *(reg8*) `$INSTANCE_NAME`_sControl_ControlByte0__CONTROL_REG =  val     &0xFF; //
                *(reg8*) `$INSTANCE_NAME`_sControl_ControlByte1__CONTROL_REG = (val>> 8)&0xFF; //
         
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 24u)
                *(reg8*) `$INSTANCE_NAME`_sControl_ControlByte0__CONTROL_REG = val &0xFF; //
                *(reg8*) `$INSTANCE_NAME`_sControl_ControlByte1__CONTROL_REG = (val>> 8)&0xFF; //
                *(reg8*) `$INSTANCE_NAME`_sControl_ControlByte2__CONTROL_REG = (val>>16)&0xFF; //
 
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 32u)
                *(reg8*) `$INSTANCE_NAME`_sControl_ControlByte0__CONTROL_REG = val &0xFF; //
                *(reg8*) `$INSTANCE_NAME`_sControl_ControlByte1__CONTROL_REG = (val>> 8)&0xFF; //
                *(reg8*) `$INSTANCE_NAME`_sControl_ControlByte2__CONTROL_REG = (val>>16)&0xFF; //
                *(reg8*) `$INSTANCE_NAME`_sControl_ControlByte3__CONTROL_REG = (val>>24)&0xFF; //
    #endif
    

    /*
    // Not work, register assignment is not contiguous->
    #if   (`$INSTANCE_NAME`_BUS_WIDTH <= 8u)
                CY_SET_REG8( `$INSTANCE_NAME`_out0_PTR,  val     &0xFF ); //
    
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 16u)
                CY_SET_REG16( `$INSTANCE_NAME`_out0_PTR,  val     &0xFFFF ); //
 
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 32u)
                CY_SET_REG32( `$INSTANCE_NAME`_out0_PTR,  val     &0xFFFFFFFF ); //
    #endif
    */
    
}

//==============================================================================
// Set control output value
//==============================================================================

uint32 `$INSTANCE_NAME`_Read()    // read control
{ 
    #if (`$INSTANCE_NAME`_BUS_WIDTH <= 8u)
        return  (uint8) CY_GET_REG8(`$INSTANCE_NAME`_out0_PTR);        //
    
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 16u)
        return  ((uint16) CY_GET_REG8(`$INSTANCE_NAME`_out0_PTR))    |
                ((uint16) CY_GET_REG8(`$INSTANCE_NAME`_out1_PTR)<<8u); // combine into  2-byte word
         
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 24u)
        return  ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_out0_PTR))     |
                ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_out1_PTR)<<8u) |
                ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_out2_PTR)<<16u); // combine into 3-byte word 
 
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 32u)
        return  ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_out0_PTR))     |
                ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_out1_PTR)<<8u) |
                ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_out2_PTR)<<16u)| 
                ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_out3_PTR)<<24u); // combine into 4-byte word
            
    #endif
}     
    
    
/* [] END OF FILE */
