/* ============================================================================
 * File Name: `$INSTANCE_NAME`.c
 * Version `$CY_MAJOR_VERSION`.`$CY_MINOR_VERSION`
 *
 * Description:
 *   DDS24: 24-bit DDS frequency generator component (v 0.0)
 *   Produces two syncronous fractional frequency outputs (out1 and out2)
 *   Outputs out1 and out2 separated by variable 8-bit phase shift [0..255]. 
 *
 * Credits:
 *   based on original IQ_DDS code by <PSoC73>:
 *   http://www.cypress.com/?app=forum&id=2492&rID=88149
 * 
 *   Special thanks to <pavloven>, <vdvorak>, <kabron>
 *
 * Note:
 *   frequency resolution = clock_frequency / 2^24
 *   frequency maximum    = clock_frequency / 2
 *   frequency minimum    = clock_frequency / 2^24
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/

#include <`$INSTANCE_NAME`.h>


  
//==============================================================================
// Set control output value
//==============================================================================
/*
void  `$INSTANCE_NAME`_Write( uint32 val ) // 
{   
    
    CY_SET_REG8( `$INSTANCE_NAME`_sts0_PTR,  val     &0xFF ); //
        
    #if (`$INSTANCE_NAME`_BUS_WIDTH > 8)
    CY_SET_REG8( `$INSTANCE_NAME`_sts1_PTR, (val>> 8)&0xFF ); //
    #endif
        
    #if (`$INSTANCE_NAME`_BUS_WIDTH > 16)
    CY_SET_REG8( `$INSTANCE_NAME`_sts2_PTR, (val>>16)&0xFF ); //
    #endif
        
    #if (`$INSTANCE_NAME`_BUS_WIDTH > 24)
    CY_SET_REG8( `$INSTANCE_NAME`_sts3_PTR, (val>>24)&0xFF ); // 
    #endif
        
}
*/
//==============================================================================
// Set control output value
//==============================================================================

uint32 `$INSTANCE_NAME`_Read()    // read control
{ 
    
    #if (`$INSTANCE_NAME`_ISR_ENABLE)
    
    
        #if (`$INSTANCE_NAME`_BUS_WIDTH <= 7)
            return  (uint8) CY_GET_REG8(`$INSTANCE_NAME`_sts0_PTR);         // single byte
    
        #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 14)
            return  ((uint16) CY_GET_REG8(`$INSTANCE_NAME`_sts0_PTR))     |
                    ((uint16) CY_GET_REG8(`$INSTANCE_NAME`_sts1_PTR)<<7u);  // combine into  2-byte word
         
        #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 21)
            return  ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts0_PTR))     |
                    ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts1_PTR)<<7u) |
                    ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts2_PTR)<<14u); // combine into 3-byte word 
 
        #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 28)
            return  ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts0_PTR))     |
                    ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts1_PTR)<<7u) |
                    ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts2_PTR)<<14u)| 
                    ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts3_PTR)<<21u); // combine into 4-byte word
        #endif
    
        
    #else   // isr_enabled = false->        
        
        #if (`$INSTANCE_NAME`_BUS_WIDTH <= 8u)
            return  (uint8) CY_GET_REG8(`$INSTANCE_NAME`_sts0_PTR);         // single byte
    
        #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 16u)
            return  ((uint16) CY_GET_REG8(`$INSTANCE_NAME`_sts0_PTR))     |
                    ((uint16) CY_GET_REG8(`$INSTANCE_NAME`_sts1_PTR)<<8u);  // combine into  2-byte word
         
        #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 24u)
            return  ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts0_PTR))     |
                    ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts1_PTR)<<8u) |
                    ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts2_PTR)<<16u); // combine into 3-byte word 
 
        #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 32u)
            return  ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts0_PTR))     |
                    ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts1_PTR)<<8u) |
                    ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts2_PTR)<<16u)| 
                    ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_sts3_PTR)<<24u); // combine into 4-byte word
        #endif
        
    #endif    

}     
    
//==============================================================================
// Set interrupt mask
//==============================================================================

void  `$INSTANCE_NAME`_WriteMask( uint32 val ) // 
{      
    #if (`$INSTANCE_NAME`_ISR_ENABLE) // todo 
        
        #if (`$INSTANCE_NAME`_BUS_WIDTH <= 7)
            CY_SET_REG8( `$INSTANCE_NAME`_mask0_PTR, (val    ) & 0x7F );   
    
        #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 14)
            CY_SET_REG8( `$INSTANCE_NAME`_mask0_PTR, (val    ) & 0x7F );     
            CY_SET_REG8( `$INSTANCE_NAME`_mask1_PTR, (val>> 7) & 0x7F );  
         
        #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 21)
            CY_SET_REG8( `$INSTANCE_NAME`_mask0_PTR, (val    ) & 0x7F );     
            CY_SET_REG8( `$INSTANCE_NAME`_mask1_PTR, (val>> 7) & 0x7F );  
            CY_SET_REG8( `$INSTANCE_NAME`_mask2_PTR, (val>>14) & 0x7F );  
 
        #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 28)
            CY_SET_REG8( `$INSTANCE_NAME`_mask0_PTR, (val    ) & 0x7F );     
            CY_SET_REG8( `$INSTANCE_NAME`_mask1_PTR, (val>> 7) & 0x7F );  
            CY_SET_REG8( `$INSTANCE_NAME`_mask2_PTR, (val>>14) & 0x7F );  
            CY_SET_REG8( `$INSTANCE_NAME`_mask3_PTR, (val>>21) & 0x7F );
        #endif
    
    #endif
        
}

//==============================================================================
// Read interrupt mask
//==============================================================================

uint32 `$INSTANCE_NAME`_ReadMask()    
{ 
    
    #if (`$INSTANCE_NAME`_BUS_WIDTH <= 8u)
        return  ( ((uint8)  CY_GET_REG8(`$INSTANCE_NAME`_mask0_PTR) & 0xFF)     );
    
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 16u)
        return  ( ((uint16) CY_GET_REG8(`$INSTANCE_NAME`_mask0_PTR) & 0x7F)     )|
                ( ((uint16) CY_GET_REG8(`$INSTANCE_NAME`_mask1_PTR) & 0x7F) << 7);   
         
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 24u)
        return  ( ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_mask0_PTR) & 0x7F)     )|
                ( ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_mask1_PTR) & 0x7F) << 7)|
                ( ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_mask2_PTR) & 0x7F) <<14);   
 
    #elif (`$INSTANCE_NAME`_BUS_WIDTH <= 32u)
        return  ( ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_mask0_PTR) & 0x7F)     )|
                ( ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_mask1_PTR) & 0x7F) << 7)|
                ( ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_mask2_PTR) & 0x7F) <<14)|   
                ( ((uint32) CY_GET_REG8(`$INSTANCE_NAME`_mask3_PTR) & 0x7F) <<21);             
    #endif
}     
    
/* [] END OF FILE */
