/* ============================================================================
 * Project Name: ShiftReg32_01a_dev
 *
 * Description:
 *   32-bit Shift Register custom component demo, realized in PLD
 *
 *   Project uses custom components ControlReg32 and ShiftReg32 to load
 *   data to the ShiftReg64 and read the output
 *   
 *   UART (through the KitProg) allows for monitoring of the output
 *   using serial terminal. 
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/


#include <project.h>
#include <stdlib.h>
#include <stdio.h>

#define BlinkLED(); {Pin_LED_Write(1); CyDelayUs(30); Pin_LED_Write(0);} // blink LED indicator

//===========================================
// data request issued
//===========================================
volatile CYBIT flag_DtrReady = 0; 
CY_ISR(isrDtr_Handler)        // DDS interrupt          
{  
    flag_DtrReady = 1;
}

//============================================
// Global variables
//============================================
char buff[64];//output UART buffer

uint32 c32, s32; 



//============================================
// Forward declarations
//============================================
void DisplayData(void); // output to terminal

void Init()
{
    CyGlobalIntEnable;

    UART_1_Start();                 // debugging terminal
    CyDelay(200);
    UART_1_PutString("\nShiftReg32 demo\r\n\n"); 
    
    CReg32_1_Write(0xFFFFFFFF);     // must write explicitly
    
      
    isrDtr_StartEx(isrDtr_Handler); // start isrDrq interrupt
    CReg_Load_Write(1);             // load ShiftReg
}


int main(void)
{
    Init();
    
    for(;;)
    {
         if (flag_DtrReady) // data latched
        {
            flag_DtrReady=0;
            BlinkLED();                  // debug..
            
            s32 = SReg32_1_Read();
            DisplayData();
        }
       
    }
    
}

//==============================================================================
// 
//==============================================================================

void DisplayData(void) // output to terminal
{ 
    //sprintf(buff, "%lX \t%lX\r\n", c32, s32 ); //
    sprintf(buff, "%lX\r\n", s32 ); //
        
    UART_1_PutString(buff);              // Send data to PC
}

/* [] END OF FILE */

